.. _csdmpy_statistics:

Statistics
^^^^^^^^^^

.. currentmodule:: csdmpy.statistics

.. rubric:: Methods Summary

.. autosummary::
   :nosignatures:

    ~integral
    ~mean
    ~var
    ~std

.. rubric:: Method Documentation

.. autofunction:: integral
.. autofunction:: mean
.. autofunction:: var
.. autofunction:: std
